Exception: PromptBuilder::ErrorResponseError

Inherits:
UnexpectedPayloadError show all
Defined in:
lib/prompt_builder/errors.rb

Overview

Raised when a response payload is an error returned by the API rather than a completion (e.g. an authentication, validation, or throttling error envelope). The message contains the error reported by the API.